from nuauth_command.client import NuauthError, Client
from nuauth_command.version import VERSION as __revision__

